@@ -87,7 +87,6 @@ const char stress_config[] =
 "#define HAVE_ATTRIBUTE_CONST\n"
 "#define HAVE_ATTRIBUTE_FAST_MATH\n"
 "#define HAVE_ATTRIBUTE_NOINLINE\n"
-"#define HAVE_ATTRIBUTE_NONSTRING\n"
 "#define HAVE_ATTRIBUTE_NORETURN\n"
 "#define HAVE_ATTRIBUTE_PACKED\n"
 "#define HAVE_ATTRIBUTE_PURE\n"
@@ -127,6 +126,7 @@ const char stress_config[] =
 "#define HAVE_BUILTIN_CLZ\n"
 "#define HAVE_BUILTIN_CLZL\n"
 "#define HAVE_BUILTIN_CLZLL\n"
+"#define HAVE_BUILTIN_COMPLEX\n"
 "#define HAVE_BUILTIN_CONSTANT_P\n"
 "#define HAVE_BUILTIN_COS\n"
 "#define HAVE_BUILTIN_COSF\n"
@@ -589,6 +589,8 @@ const char stress_config[] =
 "#define HAVE_LSETXATTR\n"
 "#define HAVE_LSTAT\n"
 "#define HAVE_LZMA_H\n"
+"#define HAVE_M128I_U\n"
+"#define HAVE_M256I_U\n"
 "#define HAVE_MADVISE\n"
 "#define HAVE_MALLOC_H\n"
 "#define HAVE_MALLOC_TRIM\n"
@@ -776,6 +778,7 @@ const char stress_config[] =
 "#define HAVE_SCTP_UDPENCAPS\n"
 "#define HAVE_SEARCH_H\n"
 "#define HAVE_SECCOMP_NOTIF_SIZES\n"
+"#define HAVE_SEED48\n"
 "#define HAVE_SELECT\n"
 "#define HAVE_SEMAPHORE_H\n"
 "#define HAVE_SEMTIMEDOP\n"
@@ -1036,6 +1039,7 @@ const char stress_config[] =
 "/* #define HAVE_ASM_PPC_DCBT */\n"
 "/* #define HAVE_ASM_PPC_DCBTST */\n"
 "/* #define HAVE_ASM_PPC_ICBI */\n"
+"/* #define HAVE_ASM_RISCV_CBO_CACHE_MANAGEMENT */\n"
 "/* #define HAVE_ASM_RISCV_CBO_ZERO */\n"
 "/* #define HAVE_ASM_RISCV_FENCE */\n"
 "/* #define HAVE_ASM_RISCV_FENCE_I */\n"
@@ -1073,6 +1077,7 @@ const char stress_config[] =
 "/* #define HAVE_GETEXECNAME */\n"
 "/* #define HAVE_GETMNTINFO */\n"
 "/* #define HAVE_GETXATTRAT */\n"
+"/* #define HAVE_HEAPSORT */\n"
 "/* #define HAVE_INIT_MB_MGR_AVX */\n"
 "/* #define HAVE_INTEL_IPSEC_MB_H */\n"
 "/* #define HAVE_LIB_IPSEC_MB */\n"
@@ -1083,6 +1088,7 @@ const char stress_config[] =
 "/* #define HAVE_MACH_MACH_H */\n"
 "/* #define HAVE_MACH_VM_STATISTICS_H */\n"
 "/* #define HAVE_MEMBARRIER */\n"
+"/* #define HAVE_MERGESORT */\n"
 "/* #define HAVE_MM_STREAM_SI128 */\n"
 "/* #define HAVE_MM_STREAM_SI32 */\n"
 "/* #define HAVE_MM_STREAM_SI64 */\n"
@@ -1093,6 +1099,7 @@ const char stress_config[] =
 "/* #define HAVE_PRAGMA_NO_HARD_DFP */\n"
 "/* #define HAVE_PTHREAD_NP_H */\n"
 "/* #define HAVE_QUOTACTL_FD */\n"
+"/* #define HAVE_RADIXSORT */\n"
 "/* #define HAVE_REMOVEXATTRAT */\n"
 "/* #define HAVE_RFORK */\n"
 "/* #define HAVE_SETXATTRAT */\n"
