@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2022-2025 Colin Ian King.
+ * Copyright (C) 2022-2026 Colin Ian King.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -93,22 +93,22 @@ typedef struct {
  * io uring submission queue info
  */
 typedef struct {
-	unsigned *head;
-	unsigned *tail;
-	unsigned *ring_mask;
-	unsigned *ring_entries;
-	unsigned *flags;
-	unsigned *array;
+	unsigned int *head;
+	unsigned int *tail;
+	unsigned int *ring_mask;
+	unsigned int *ring_entries;
+	unsigned int *flags;
+	unsigned int *array;
 } stress_uring_io_sq_ring_t;
 
 /*
  * io uring completion queue info
  */
 typedef struct {
-	unsigned *head;
-	unsigned *tail;
-	unsigned *ring_mask;
-	unsigned *ring_entries;
+	unsigned int *head;
+	unsigned int *tail;
+	unsigned int *ring_mask;
+	unsigned int *ring_entries;
 	struct io_uring_cqe *cqes;
 } stress_uring_io_cq_ring_t;
 
@@ -153,7 +153,7 @@ static const char *stress_io_uring_opcode_name(const uint8_t opcode);
  *  shim_io_uring_setup
  *	wrapper for io_uring_setup()
  */
-static inline int shim_io_uring_setup(unsigned entries, struct io_uring_params *p)
+static inline int shim_io_uring_setup(unsigned int entries, struct io_uring_params *p)
 {
 	return (int)syscall(__NR_io_uring_setup, entries, p);
 }
@@ -250,7 +250,7 @@ static int stress_setup_io_uring(
 			args->name, errno, strerror(errno));
 		return EXIT_FAILURE;
 	}
-	submit->sq_size = p.sq_off.array + p.sq_entries * sizeof(unsigned);
+	submit->sq_size = p.sq_off.array + p.sq_entries * sizeof(unsigned int);
 	submit->cq_size = p.cq_off.cqes + p.cq_entries * sizeof(struct io_uring_cqe);
 	if (p.features & IORING_FEAT_SINGLE_MMAP) {
 		if (submit->cq_size > submit->sq_size)
@@ -285,16 +285,16 @@ static int stress_setup_io_uring(
 		}
 	}
 
-	sring->head = VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.head);
-	sring->tail = VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.tail);
-	sring->ring_mask = VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.ring_mask);
-	sring->ring_entries = VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.ring_entries);
-	sring->flags = VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.flags);
-	sring->array = VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.array);
+	sring->head = (unsigned int *)VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.head);
+	sring->tail = (unsigned int *)VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.tail);
+	sring->ring_mask = (unsigned int *)VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.ring_mask);
+	sring->ring_entries = (unsigned int *)VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.ring_entries);
+	sring->flags = (unsigned int *)VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.flags);
+	sring->array = (unsigned int *)VOID_ADDR_OFFSET(submit->sq_mmap, p.sq_off.array);
 
 	submit->sqes_entries = p.sq_entries;
 	submit->sqes_size = p.sq_entries * sizeof(struct io_uring_sqe);
-	submit->sqes_mmap = stress_mmap_populate(NULL, submit->sqes_size,
+	submit->sqes_mmap = (struct io_uring_sqe *)stress_mmap_populate(NULL, submit->sqes_size,
 			PROT_READ | PROT_WRITE, MAP_SHARED,
 			submit->io_uring_fd, IORING_OFF_SQES);
 	if (submit->sqes_mmap == MAP_FAILED) {
@@ -308,11 +308,11 @@ static int stress_setup_io_uring(
 		return EXIT_NO_RESOURCE;
 	}
 
-	cring->head = VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.head);
-	cring->tail = VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.tail);
-	cring->ring_mask = VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.ring_mask);
-	cring->ring_entries = VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.ring_entries);
-	cring->cqes = VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.cqes);
+	cring->head = (unsigned int *)VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.head);
+	cring->tail = (unsigned int *)VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.tail);
+	cring->ring_mask = (unsigned int *)VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.ring_mask);
+	cring->ring_entries = (unsigned int *)VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.ring_entries);
+	cring->cqes = (struct io_uring_cqe *)VOID_ADDR_OFFSET(submit->cq_mmap, p.cq_off.cqes);
 
 	return EXIT_SUCCESS;
 }
@@ -354,19 +354,19 @@ static inline int stress_io_uring_complete(
 {
 	stress_uring_io_cq_ring_t *cring = &submit->cq_ring;
 	struct io_uring_cqe *cqe;
-	unsigned head = *cring->head;
+	unsigned int head = *cring->head;
 	int ret = EXIT_SUCCESS;
 
 	for (;;) {
-		stress_asm_mb();
+		stress_io_uring_user_data_t *user_data;
 
+		stress_asm_mb();
 		/* Empty? */
 		if (head == *cring->tail)
 			break;
 
 		cqe = &cring->cqes[head & *submit->cq_ring.ring_mask];
-		stress_io_uring_user_data_t *const user_data =
-			(stress_io_uring_user_data_t *)(uintptr_t)cqe->user_data;
+		user_data = (stress_io_uring_user_data_t *)(uintptr_t)cqe->user_data;
 		if (cqe->res < 0) {
 			int err;
 
@@ -434,7 +434,7 @@ static int stress_io_uring_submit(
 	const void *extra_data)
 {
 	stress_uring_io_sq_ring_t *sring = &submit->sq_ring;
-	unsigned idx = 0, tail = 0, next_tail = 0;
+	unsigned int idx = 0, tail = 0, next_tail = 0;
 	struct io_uring_sqe *sqe;
 	int ret;
 
@@ -499,11 +499,11 @@ static void OPTIMIZE3 stress_io_uring_async_cancel_setup(
 	struct io_uring_sqe *sqe,
 	const void *extra_info)
 {
-	(void)io_uring_file;
-
 	const struct io_uring_sqe *sqe_to_cancel =
 		(const struct io_uring_sqe *)extra_info;
 
+	(void)io_uring_file;
+
 	(void)shim_memset(sqe, 0, sizeof(*sqe));
 	sqe->fd = sqe_to_cancel->fd;
 	sqe->flags = 2;
@@ -609,7 +609,7 @@ static void OPTIMIZE3 stress_io_uring_read_setup(
 	sqe->fd = io_uring_file->fd;
 	sqe->opcode = IORING_OP_READ;
 	sqe->addr = (uintptr_t)io_uring_file->iovecs[0].iov_base;
-	sqe->len = io_uring_file->iovecs[0].iov_len;
+	sqe->len = (uint32_t)io_uring_file->iovecs[0].iov_len;
 	sqe->off = (uint64_t)io_uring_rand ?
 			(stress_mwc8() * io_uring_file->blocks) : 0;
 }
@@ -631,7 +631,7 @@ static void OPTIMIZE3 stress_io_uring_write_setup(
 	sqe->fd = io_uring_file->fd;
 	sqe->opcode = IORING_OP_WRITE;
 	sqe->addr = (uintptr_t)io_uring_file->iovecs[0].iov_base;
-	sqe->len = io_uring_file->iovecs[0].iov_len;
+	sqe->len = (uint32_t)io_uring_file->iovecs[0].iov_len;
 	sqe->off = (uint64_t)io_uring_rand ?
 			(stress_mwc8() * io_uring_file->blocks) : 0;
 }
@@ -819,11 +819,11 @@ static void OPTIMIZE3 stress_io_uring_setxattr_setup(
 	struct io_uring_sqe *sqe,
 	const void *extra_info)
 {
+	static char attr_value[] = "ioring-xattr-data";
+
 	(void)io_uring_file;
 	(void)extra_info;
 
-	static char attr_value[] = "ioring-xattr-data";
-
 	(void)shim_memset(sqe, 0, sizeof(*sqe));
 	sqe->opcode = IORING_OP_SETXATTR;
 	sqe->off = (uintptr_t)attr_value;
@@ -847,11 +847,11 @@ static void OPTIMIZE3 stress_io_uring_getxattr_setup(
 	struct io_uring_sqe *sqe,
 	const void *extra_info)
 {
+	static char attr_value[128];
+
 	(void)io_uring_file;
 	(void)extra_info;
 
-	static char attr_value[128];
-
 	(void)shim_memset(sqe, 0, sizeof(*sqe));
 	sqe->opcode = IORING_OP_GETXATTR;
 	sqe->off = (uintptr_t)attr_value;
@@ -1005,7 +1005,7 @@ static int stress_io_uring_child(stress_args_t *args, void *context)
 	io_uring_file.blocks = blocks;
 	io_uring_file.block_size = block_size;
 	io_uring_file.iovecs_sz = blocks * sizeof(*io_uring_file.iovecs);
-	io_uring_file.iovecs =
+	io_uring_file.iovecs = (struct iovec *)
 		stress_mmap_populate(NULL, io_uring_file.iovecs_sz,
 			PROT_READ | PROT_WRITE,
 			MAP_SHARED | MAP_ANONYMOUS, -1, 0);
